.. currentmodule:: revl

.. _reference:

API Reference
=============

The whole public interface of Revl is described here.

All of the library's content is accessible from within the only module
``revl``.

.. toctree::
   :maxdepth: 2

   command_evaluation
   command_functions
   misc
